#ifndef _FONTS_ST
#define _FONTS_ST

struct font_descriptor
	{
	int Type;					/*		name 	(Required) The type of PDF object that this dictionary describes; must be
																FontDescriptor for a font descriptor.	*/
	int Ascent;				/* number (Required) The maximum height above the baseline reached by glyphs in this
																font, excluding the height of glyphs for accented characters.	*/
	int CapHeight;		/* number (Required) The y coordinate of the top of flat capital letters, measured from
																the baseline.	*/
	int Descent;			/*		number	(Required) The maximum depth below the baseline reached by glyphs in this
																font. The value is a negative number.	*/
	unsigned long Flags;	/*		integer	(Required) A collection of flags defining various characteristics of the font
																(see Section 5.7.1, Font Descriptor Flags).	*/
	struct Rectangle FontBBox;	/*	rectangle (Required) A rectangle (see Section 3.8.3, Rectangles), expressed in the
																glyph coordinate system, specifying the font bounding box. This is the smallest
																rectangle enclosing the shape that would result if all of the glyphs of the
																font were placed with their origins coincident and then filled.	*/
	char FontName[32];			/*	name	(Required) The PostScript name of the font. This should be the same as the
																value of BaseFont in the font or CIDFont dictionary that refers to this font
																descriptor.	*/
	int ItalicAngle;	/*	number	(Required) The angle, expressed in degrees counterclockwise from the vertical,
																of the dominant vertical strokes of the font. (For example, the 9-oclock
																position is 90 degrees, and the 3-oclock position is 90 degrees.) The value is
																negative for fonts that slope to the right, as almost all italic fonts do.	*/
	int StemV;				/*		number	(Required) The width, measured in the x direction, of the dominant vertical
																stems of glyphs in the font.	*/
	int AvgWidth;			/*	number	(Optional) The average width of glyphs in the font. Default value: 0.
																FontFile	stream	(Optional) A stream containing a Type 1 font program (see Section 5.8, Embedded
																Font Programs).	*/
	unsigned long FontFile2;	/*	stream	(Optional; PDF 1.1) A stream containing a TrueType font program (see
																Section 5.8, Embedded Font Programs).	*/
	unsigned long FontFile3;	/*	stream	(Optional; PDF 1.2) A stream containing a font program other than Type 1 or
																TrueType. The format of the font program is specified by the Subtype entry
																in the stream dictionary (see Section 5.8, Embedded Font Programs, and
																implementation note 45 in Appendix H).
																Note: At most, only one of the FontFile, FontFile2, and FontFile3 entries may be
																present.	*/
	int Leading;			/*		number	(Optional) The desired spacing between baselines of consecutive lines of text.
																Default value: 0.	*/
	int MaxWidth;			/*	number	(Optional) The maximum width of glyphs in the font. Default value: 0.	*/
	int MissingWidth;	/*	number	(Optional) The width to use for character codes whose widths are not speci-
																fied in a font dictionarys Widths array. This has a predictable effect only if all
																such codes map to glyphs whose actual widths are the same as the Missing-
																Width value. Default value: 0.	*/
	int StemH;				/*		number	(Optional) The vertical width of the dominant horizontal stems of glyphs in
																the font. Default value: 0.	*/
	int XHeight;			/*		number	(Optional) The y coordinate of the top of flat nonascending lowercase letters,
																measured from the baseline. Default value: 0.	*/
	unsigned long CharSet;	/*		string	(Optional; meaningful only in Type 1 fonts; PDF 1.1) A string listing the character
																names defined in a subset font. The names in this string must be in PDF
																syntaxthat is, each name preceded by a slash (/). The names can appear in
																any order. The name .notdef should be omitted; it is assumed to exist in the
																font subset. If this entry is absent, the only indication of a subset font is the
																subset tag in the FontName entry (see Section 5.5.3, Font Subsets).	*/
	};


struct encoding
	{
	int type;
	int base;
	int *differences;
	};

struct fonts
	{
	char type;							/*	Type of the fonts:
															0 - TrueType
															1 - Type 1
															2 - Type 2
															3 - Type 3
													*/
	unsigned long TT_id;		/* TrueType and Type1 font ID	*/
	char effect;						/*	0 - bold
															1 - light
															2 - italic
															3 - underline
															4 - 
															5 - shadow
														*/
	int italic_angle;
	char name[32];
	int first_char, last_char;
	int *width_table;				/* Width table	*/
	struct encoding encoding;
	int base_font;
	struct font_descriptor *descriptor;
	int loaded_fonts;				/* How many fonts there are in memory	*/
	};




#define TXT_BOLD				1
#define TXT_ITALIC			4
#define TXT_UNDERLINE		8
#define TXT_SHADOW			32

#endif


struct Character_encoding
	{
	char character[5];				/* Optional	*/
	char name[26];				/* Must			*/
	struct _code
		{
		int standard, mac, win, pdf;
		int new_code;
		}code;
	};

#define LATIN_SIZE		235
#define MAC_SIZE			170
#define SYMBOL_SIZE		190
#define ZAPF_SIZE			190