extern char *outline_commands[];
extern char *outline_dictionary_commands[];

#define OUTLINE_HEIGHT	14

#define OUTLINE_DICT_TITLE	1
#define OUTLINE_DICT_PARENT	2
#define OUTLINE_DICT_PREV		3
#define OUTLINE_DICT_NEXT		4
#define OUTLINE_DICT_FIRST	5
#define OUTLINE_DICT_LAST		6
#define OUTLINE_DICT_COUNT	7
#define OUTLINE_DICT_DEST		8
#define OUTLINE_DICT_A			9
#define OUTLINE_DICT_SE			10


struct PDF_Outline_dictionary
	{
	char *Title;				/* text string		(Required) The text to be displayed on the screen for this item.	*/
	unsigned long title;		/* Where the title is stored		*/
	BOOLEAN opened;			/* Is the entry in the window opened?	yes: TRUE, no: FALSE	*/

	struct PDF_Outline_dictionary *parent;
	long Parent;				/* dictionary		(Required; must be an indirect reference) The parent of this item in the 
													outline hierarchy. The parent of a top-level  item is the outline dictionary itself.	*/

	struct PDF_Outline_dictionary *prev;
	long Prev;					/* dictionary		(Required for all but the first item at each level; must be an indirect reference) The previous 
												item at this outline level.		*/

	struct PDF_Outline_dictionary *next;
	long Next;					/*	dictionary		(Required for all but the last item at each level; must be an indirect reference) 
													The next item at this outline level.	*/

	struct PDF_Outline_dictionary *first;
	long First;					/* dictionary		(Required if the item has any descendants; must be an indirect reference) 
												The first of this items immediate children in the outline hierarchy.	*/
	long Last;					/* dictionary		(Required if the item has any descendants; must be an indirect reference) The 
												last of this items immediate children in the outline hierarchy.	*/
	int Count;					/*	integer			(Required if the item has any descendants) If the item is open, 
													the total number of its open descendants at all lower levels of the outline hierarchy. If the 
													item is closed, a negative integer whose absolute value specifies how many descendants 
													would appear if the item were reopened.	*/
	long Dest;					/* name, string or array	(Optional; not permitted if an A entry is present) The destination to be 
												displayed when this item is activated (see Section 7.2.1, Destinations; see also 
												implementation  note 49 in Appendix H).	*/
	long A;							/* dictionary		(Optional; PDF 1.1; not permitted if a Dest entry is present)
												The action to be performed when this item is activated (see 	Section 7.5, Actions).	*/
	long SE;						/*	dictionary		(Optional; PDF 1.3; must be an indirect reference) The structure element to which 
													the item refers (see Structure Hierarchy on page 486).	*/
	int level;					/*	 Level:
													0 - 1.
													1 - 1.1
													2 - 1.1.1
													3 - 1.1.1.1	*/
	};



#define OUTLINE_TYPE		1
#define OUTLINE_FIRST		2
#define OUTLINE_LAST		3
#define OUTLINE_COUNT		4

struct	PDF_Outline
	{

	int Type;						/*	name (Optional) The type of PDF object that this dictionary describes; if present, must be Outlines for an outline dictionary.	*/

	long First;					/* dictionary		(Required; must be an indirect reference) An outline item dictionary
												representing the first top-level item in the outline.		*/

	long Last;					/* dictionary		(Required; must be an indirect reference) An outline item dictionary 
													representing the last top-level item in the outline.	*/

	int Count;					/*	integer			(Required if the document has any open outline entries) The total number of open 
													items at all levels of the outline. This entry should be omitted if there are no open outline items.	*/

	struct PDF_Outline_dictionary *first_object;
	};




/*
Example 7.1
21 0 obj
<< /Count 6
/First 22 0 R
/Last 29 0 R
>>
endobj
22 0 obj
<< /Title ( Chapter 1)
/Parent 21 0 R
/Next 26 0 R
/First 23 0 R
/Last 25 0 R
/Count 3
/Dest [ 3 0 R /XYZ 0 792 0]
>>
endobj
*/


/*
EXAMPLE:

. Introduction							->next (shows the '.Read me')
. Read me										->next (shows '1. First paragraph')
1. First paragraph					->next (shows '2. Second paragraph')
														->first (shows '1.1 First subparagraph')
	1.1 First subparagraph		->next (shows '1.2 Second one')
														->parent (shows '1. First paragraph')
	1.2 Second one						->next=NULL, ->parent (shows '1. First...')
2. Second paragraph					->next (shows '3. hi hi')
														->first (shows '2.1 ...')
	2.1 First									->next (shows '2.2...')
														->first (shows '2.1.1 First...')
		2.1.1 First first	
		2.1.2 Second second
	2.2 Second
3. hi hi
4. ha ha										->next (shows '. Suplement')
. Suplemet
. Bibliography
. Summary

*/